"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.trackScreenView = function (eventDef) { return function (action, prevState, nextState) {
    var event = eventDef(action, prevState, nextState);
    var screenName = event.screenName, customDimensions = event.customDimensions;
    var shouldSendCustomDimensionsEvent = Boolean(customDimensions);
    if (!shouldSendCustomDimensionsEvent) {
        return {
            hitType: 'pageview',
            page: screenName,
        };
    }
    return {
        hitType: 'pageviewCustomDimensions',
        page: screenName,
        customDimensionDict: customDimensions,
    };
}; };
exports.trackEvent = function (eventDef) { return function (action, prevState, nextState) {
    var event = eventDef(action, prevState, nextState);
    var category = event.category, label = event.label, value = event.value, customDimensions = event.customDimensions;
    var shouldSendCustomDimensionsEvent = Boolean(customDimensions);
    if (!shouldSendCustomDimensionsEvent) {
        return {
            hitType: 'event',
            eventCategory: category,
            eventAction: event.action,
            eventLabel: label,
            eventValue: value,
        };
    }
    return {
        hitType: 'eventCustomDimensions',
        eventCategory: category,
        eventAction: event.action,
        eventLabel: label,
        eventValue: value,
        customDimensionDict: customDimensions,
    };
}; };
exports.trackPurchase = function (eventDef) { return function (action, prevState, nextState) {
    var event = eventDef(action, prevState, nextState);
    var product = event.product, transaction = event.transaction, category = event.category;
    return {
        hitType: 'purchase',
        eventAction: event.action,
        product: product,
        transaction: transaction,
        eventCategory: category,
    };
}; };
exports.trackTiming = function (eventDef) { return function (action, prevState, nextState) {
    var event = eventDef(action, prevState, nextState);
    var category = event.category, value = event.value, label = event.label, name = event.name;
    return {
        hitType: 'timing',
        timingCategory: category,
        timingValue: value,
        timingVar: name,
        timingLabel: label,
    };
}; };
exports.trackSocialInteraction = function (eventDef) { return function (action, prevState, nextState) {
    var event = eventDef(action, prevState, nextState);
    var network = event.network, target = event.target;
    return {
        hitType: 'social',
        socialNetwork: network,
        socialAction: event.action,
        socialTarget: target,
    };
}; };
exports.setUser = function (eventDef) { return function (action, prevState, nextState) {
    var userId = eventDef(action, prevState, nextState);
    return {
        hitType: 'user',
        userId: userId,
    };
}; };
exports.setClient = function (eventDef) { return function (action, prevState, nextState) {
    var clientId = eventDef(action, prevState, nextState);
    return {
        hitType: 'client',
        clientId: clientId,
    };
}; };
exports.trackException = function (eventDef) { return function (action, prevState, nextState) {
    var event = eventDef(action, prevState, nextState);
    var description = event.description, isFatal = event.isFatal;
    return {
        hitType: 'exception',
        exDescription: description,
        exFatal: isFatal,
    };
}; };
